//
// C++ Interface: cplugin
//
// Description: see below
//
//
// Author: Tomas Mecir <kmuddy@kmuddy.net>, (C) 2003
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef CPLUGIN_H
#define CPLUGIN_H

#include <qobject.h>

#include "ctextchunk.h"

// *** DISABLED ***
// *** DISABLED ***

// see cPluginManager for info

/**
This class represents one plug-in for KMuddy. It is created by a plug-in factory.

Currently, only very basic features are supported.

The cSession pointer is passed in all routines, so that you can distinguish between events in
different connections. It can be used to no other purpose, as the cSession class is not available
to the plug-in as of now, thus you cannot dereference the pointer (will be changed after 1.0).

The best way to store session-related stuff in your plug-in is to create some struct/class, e.g.
mySettings, then make a mapping
map <cSession *, mySettings *> settings;
that will manage the pointers, adding/removing them when connected/disconnected events come.

@author Tomas Mecir
*/

class cPlugin : public QObject
{
Q_OBJECT
public:
#if 0
  cPlugin (QObject *parent = 0, const char *name = 0);
  ~cPlugin ();

  /** priority in which this plug-in receives texts/events. Lower numbers means higher priority. */
  int priority () { return 50; };

  /** raw data from the socket, before any processing; data can be modified by the plug-in
  if desired */
  virtual void rawData (cSession *, char *data) {};
  /** raw data, after MCCP decompression, data is equivalent to rawData if MCCP is not used;
  data can be modified by plug-in if desired */
  virtual void decompressedData (cSession *, char *data) {};
  virtual void preprocessInput (cSession *, QString &data) {};
  /** process one line of input from the MUD; called after telnet/ANSI processing;
  this function is called TWICE for each line, first time before triggers get the line, second
  time right before displaying the line (or discarding if gagged).
  Data can be modified is desired.
  @param sess session pointer
  @param phase which phase are we in? 1 means before triggers, 2 means after triggers
  @param chunk the line
  @param gagged only valid if phase is 2, it says whether this line is to be gagged */
  virtual void processInput (cSession *, int phase, cTextChunk *chunk, bool gagged) {};
  /** prompt that will be displayed; you can modify it is desired */
  virtual void processPrompt (cSession *, cTextChunk *chunk) {};
  /** Command that is to be sent to the MUD. Aliases have already been expanded.
  Command can be modified if desired. If you set dontSend to true, the command won't be
  sent and plug-ins with lower priority won't receive this command either. */
  virtual void processCommand (cSession *, QString &command, bool &dontSend) {};
  /** Macro entered on command line, return true if you've processed it */
  virtual bool processMacro (cSession *, const QString &macro, const QString &params)
      { return false; };
  /** an event has occured, parameters depend on event type */
  virtual void event (cSession *, const QString &type, const QString &name, const QString &par1,
      const QString &par2) {};
//signals:
  /** emit this signal if you want to display a system message */
  void systemMessage (cSession *, const QString &message);
  /** emit this signal if you want to display a line with certain fg/bg of letters */
  void displayLine (cSession *, cTextChunk *chunk);

#endif  // 0
};

#endif
